Module stage

Module stage 

The Stage trait.

Stages receive items one at a time and emit zero or more outputs via an Emit handle. The closure-based adapters (map, filter, …) are exposed as methods on crate::PipelineBuilder.

Traits

Stage
Transform stage in a pipeline.