pub trait ByteSize { // Required method fn byte_size(&self) -> usize; }
Opt-in trait for items that contribute a measurable byte size to a batch. Required when BatchPolicy::max_bytes is set.
BatchPolicy::max_bytes
Number of bytes this item contributes to the batch.